
## Contributing

### Environment Setup


#### Pre-Commit Hooks
This project makes use of pre-commit hooks in order to maintain a consistent codebase regardless of personal opinion or preferred coding style.

To do this, the following tools are run in a pre-commit hook
1. Black
2. ISort
3. flake8
